Modules
======================================

.. .. toctree::
..    :maxdepth: 4
..    :caption: Contents:


Image augmentation
------------------------------------------
.. automodule:: deoxys_image.augmentation
   :members:
   :undoc-members:

Image Transformation
-------------------------------------------

Affine Transformation
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
.. automodule:: deoxys_image.affine_transform
   :members:
   :undoc-members:


Point operation
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
.. automodule:: deoxys_image.point_operation
   :members:
   :undoc-members:

Convolutional operation
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
.. automodule:: deoxys_image.filters
   :members:
   :undoc-members:


Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
